@@ -1,7 +1,7 @@
 /*
  * aurora - Communications with Magnetek Aurora Inverter
  *
- * Copyright (C) 2006-2016 Curtis J. Blank curt@curtronics.com
+ * Copyright (C) 2006-2019 Curtis J. Blank curt@curtronics.com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -88,10 +88,11 @@
  * modified 11-apr-2014 cjb	1. correct reporting wrong model when -Q is not used 
  * modified 11-jul-2016 cjb	1. if returning _ERROR_ and veborse print out debug info
  *				2. change how _ERROR_ is determined in float routines
+ * modified 12-mar-2019 cjb	1. correct a typo in GetPNC CMD 105 error reporting
  *
  */
 
-char     VersionC[7] = "1.9.3";
+char     VersionC[7] = "1.9.4";
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -305,7 +306,7 @@ int GetPNC(int fdser, int yAddress)
     char PartNumber[7];
 
     if (ModelID != 'C' && ModelID != 'M' && ModelID != 'L' && ModelID != 'B' && ModelID != 'A') {
-        fprintf(outfp, "\nCannot query for Part Number, doea not appear to be a Central inverter (%c)\n\n", ModelID);
+        fprintf(outfp, "\nCannot query for Part Number, does not appear to be a Central inverter (%c)\n\n", ModelID);
         return(-1);
     }
     PartNumber[0] = '\0';
